@@ -7,7 +7,11 @@ PREFIX=${PREFIX-"/usr/local"}
 
 ### Databases
 FORTUNES=`find data -maxdepth 1 -type f | sed "s?data/??"`
-FORTUNESMORE=`find data-more -maxdepth 1 -type f | sed "s?data-more/??"`
+if [ -d data-more ] ; then
+  FORTUNESMORE=`find data-more -maxdepth 1 -type f | sed "s?data-more/??"`
+else
+  FORTUNESMORE=""
+fi
 DIRS=`find data -maxdepth 1 -type d | sed "s?data/??" | sed "/data/d"`
 
 DOC="README AUTHORS NEWS LIESMICH GPL-Deutsch"
